from .builder import build
from .analyzer import analyze

__version__ = "0.3.9"
__author__ = [{"Henry Cook":"henryscookolaizola@gmail.com"}, {"Alejandro Sempere":"asempere@colegioaleman.net"}, "Pablo Pérez"]